@@ -1,20 +1,14 @@
-# -*- coding: utf-8 -*-
-"""
-@author: Philipp Temminghoff
-"""
+from __future__ import annotations
 
-from qtpy.QtCharts import QtCharts
 from prettyqt import core
+from prettyqt.qt import QtCharts
 
 
 QtCharts.QAbstractSeries.__bases__ = (core.Object,)
 
 
 class AbstractSeries(QtCharts.QAbstractSeries):
-
-    """
-    QAbstractSeries with some custom properties
-    """
+    """QAbstractSeries with some custom properties."""
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
