@@ -1,25 +1,14 @@
-# -*- coding: utf-8 -*-
-"""
-@author: Philipp Temminghoff
-"""
+from __future__ import annotations
 
-from qtpy import QtCore
-from qtpy.QtCharts import QtCharts
-from prettyqt import core, charts
-
-STYLES = {QtCore.Qt.SolidLine: "Solid",
-          QtCore.Qt.DotLine: "Dot",
-          QtCore.Qt.DashDotLine: "Dash-dot"}
+from prettyqt import charts, core
+from prettyqt.qt import QtCharts, QtCore
 
 
 QtCharts.QLineSeries.__bases__ = (charts.XYSeries,)
 
 
 class LineSeries(QtCharts.QLineSeries):
-
-    """
-    QLineSeries with some custom properties
-    """
+    """QLineSeries with some custom properties."""
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -36,4 +25,4 @@ class LineSeries(QtCharts.QLineSeries):
 
 if __name__ == "__main__":
     line = LineSeries()
-    line.append(0, 1)
+    line += QtCore.QPointF(1, 1)
