@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
-"""
-@author: Philipp Temminghoff
-"""
+from __future__ import annotations
 
-from qtpy.QtCharts import QtCharts
 from prettyqt import charts
+from prettyqt.qt import QtCharts
 
 
 QtCharts.QScatterSeries.__bases__ = (charts.XYSeries,)
