@@ -1,11 +1,7 @@
-# -*- coding: utf-8 -*-
-"""
-@author: Philipp Temminghoff
-"""
-
-from qtpy import QtCore
+from __future__ import annotations
 
 from prettyqt import core
+from prettyqt.qt import QtCore
 
 
 QtCore.QAbstractListModel.__bases__ = (core.AbstractItemModel,)
