@@ -1,13 +1,9 @@
-# -*- coding: utf-8 -*-
-"""
-@author: Philipp Temminghoff
-"""
+from __future__ import annotations
 
-from qtpy import QtCore
+from prettyqt.qt import QtCore
 
 
 class DirIterator(QtCore.QDirIterator):
-
     def __iter__(self):
         return self
 
