@@ -1,10 +1,12 @@
-# -*- coding: utf-8 -*-
-"""
-"""
+from __future__ import annotations
 
-from typing import Optional, Union
+from typing import TYPE_CHECKING, Any
 
-from qtpy import QtCore
+from prettyqt.qt import QtCore
+
+
+if TYPE_CHECKING:
+    from prettyqt import core
 
 
 class RegularExpressionMatch(QtCore.QRegularExpressionMatch):
@@ -15,12 +17,21 @@ class RegularExpressionMatch(QtCore.QRegularExpressionMatch):
         self.endpos = None
 
     def __repr__(self):
-        return "RegularExpressionMatch()"
+        return f"{type(self).__name__}()"
 
-    def __getitem__(self, item):
-        return self.group(item)
+    def __getitem__(self, item: int | str) -> str:
+        captured = self.captured(item)
+        if not captured:
+            raise KeyError(item)
+        return captured
 
-    def group(self, *groups) -> Union[tuple, str]:
+    def __bool__(self):
+        return self.isValid()
+
+    def get_match_type(self) -> core.regularexpression.MatchTypeStr:
+        return core.regularexpression.MATCH_TYPE.inverse[self.matchType()]
+
+    def group(self, *groups: int | str) -> tuple[str, ...] | str:
         if len(groups) > 1:
             return tuple(self.captured(i) for i in groups)
         if len(groups) == 0:
@@ -35,9 +46,9 @@ class RegularExpressionMatch(QtCore.QRegularExpressionMatch):
             for i in range(self.re.captureCount())
         )
 
-    def groupdict(self, default=None) -> dict:
+    def groupdict(self, default=None) -> dict[str, Any]:
         if self.lastindex is None:
-            return dict()
+            return {}
         groups = [
             self.group(i) if i <= self.lastindex else default
             for i in range(self.re.captureCount())
@@ -51,26 +62,26 @@ class RegularExpressionMatch(QtCore.QRegularExpressionMatch):
     def end(self, group: int = 0) -> int:
         return self.capturedEnd(group)
 
-    def span(self, group: int = 0) -> tuple:
+    def span(self, group: int = 0) -> tuple[int, int]:
         return (self.capturedStart(group), self.capturedEnd(group))
 
     @property
-    def lastindex(self) -> Optional[int]:
+    def lastindex(self) -> int | None:
         idx = self.lastCapturedIndex()
         return None if idx == -1 else idx
 
     @property
-    def lastgroup(self) -> Optional[str]:
+    def lastgroup(self) -> str | None:
         if self.lastCapturedIndex() == -1:
             return None
         return self.re.namedCaptureGroups()[self.lastCapturedIndex()]
 
     @property
-    def re(self):
+    def re(self) -> QtCore.QRegularExpression:
         return self.regularExpression()
 
     @property
-    def partial(self):
+    def partial(self) -> bool:
         return self.hasPartialMatch()
 
 
