@@ -1,21 +1,22 @@
-# -*- coding: utf-8 -*-
-"""
-"""
+from __future__ import annotations
 
-from typing import Dict
+from typing import Callable
 
 from prettyqt import constants
+from prettyqt.qt import QtCore
 
 
-class SelectionMixin(object):
+class SelectionMixin:
 
-    CHECKSTATE: Dict = {}  # column: identifier
+    CHECKSTATE: dict[int, Callable] = {}  # column: identifier
+    dataChanged: QtCore.Signal
+    DATA_ROLE: int
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.selected = dict()
+    def __init__(self):
+        super().__init__()
+        self.selected = {}
 
-    def setData(self, index, value, role):
+    def setData(self, index: QtCore.QModelIndex, value, role) -> bool:
         if not index.isValid():
             return False
         elif role == constants.CHECKSTATE_ROLE:
@@ -23,9 +24,9 @@ class SelectionMixin(object):
             self.selected[name] = not self.selected[name]
             self.dataChanged.emit(index, index)
             return True
-        return super().setData(index, value, role)
+        return super().setData(index, value, role)  # type: ignore
 
-    def data(self, index, role=constants.DISPLAY_ROLE):
+    def data(self, index: QtCore.QModelIndex, role=constants.DISPLAY_ROLE):
         if not index.isValid():
             return False
         if role == constants.CHECKSTATE_ROLE:
@@ -35,15 +36,15 @@ class SelectionMixin(object):
                 if name not in self.selected:
                     self.selected[name] = selected
                 return selected
-        return super().data(index, role)
+        return super().data(index, role)  # type: ignore
 
-    def flags(self, index):
-        flags = super().flags(index)
+    def flags(self, index: QtCore.QModelIndex):
+        flags = super().flags(index)  # type: ignore
         if index.column() in self.CHECKSTATE:
             return flags | constants.IS_CHECKABLE
         return flags
 
-    def _get_selection_id(self, index):
+    def _get_selection_id(self, index: QtCore.QModelIndex):
         item = index.data(self.DATA_ROLE)
         id_fn = self.CHECKSTATE.get(index.column())
         if id_fn:
