@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-"""
-"""
+from __future__ import annotations
 
 import pathlib
 
@@ -8,16 +6,13 @@ from prettyqt import gui
 
 
 class PathValidator(gui.Validator):
-    def __getstate__(self):
-        return dict()
-
-    def __setstate__(self, state):
-        self.__init__()
+    def __eq__(self, other: object):
+        return isinstance(other, PathValidator)
 
     def validate(self, text: str, pos: int = 0):
         if pathlib.Path(text).exists():
-            return (self.Acceptable, text, pos)
-        return (self.Intermediate, text, pos)
+            return self.State.Acceptable, text, pos
+        return self.State.Intermediate, text, pos
 
 
 if __name__ == "__main__":
@@ -28,4 +23,4 @@ if __name__ == "__main__":
     widget = widgets.LineEdit("This is a test")
     widget.setValidator(val)
     widget.show()
-    app.exec_()
+    app.main_loop()
