@@ -1,20 +1,22 @@
-# -*- coding: utf-8 -*-
-"""custom_widgets module
-"""
+"""Module containing custom widget classes."""
 
 from .image import Image
 from .listinput import ListInput
 from .booldicttoolbutton import BoolDictToolButton
 from .optionalwidget import OptionalWidget
+from .collapsibleframe import CollapsibleFrame
+from .expandableline import ExpandableLine
 from .singlelinetextedit import SingleLineTextEdit
 from .regexinput import RegexInput
 from .mappedcheckbox import MappedCheckBox
-from .promptlineedit import PromptLineEdit
 from .logtextedit import LogTextEdit
 from .flagselectionwidget import FlagSelectionWidget
 from .stringornumberwidget import StringOrNumberWidget
 from .iconlabel import IconLabel
+from .iconwidget import IconWidget
 from .flowlayout import FlowLayout
+from .borderlayout import BorderLayout
+from .completionwidget import CompletionWidget
 from .sidebarwidget import SidebarWidget
 from .colorchooserbutton import ColorChooserButton
 from .filechooserbutton import FileChooserButton
@@ -26,26 +28,38 @@ from .waitingspinner import WaitingSpinner
 from .markdownwidget import MarkdownWindow
 from .imageviewer import ImageViewer
 from .popupinfo import PopupInfo
-from .buttondelegate import ButtonDelegate
-from .radiodelegate import RadioDelegate
 from .selectionwidget import SelectionWidget
 from .codeeditor import CodeEditor
-from .regexeditor.editor import RegexEditorWidget
+from .roundprogressbar import RoundProgressBar
+from .subsequencecompleter import SubsequenceCompleter
+from .framelesswindow import FramelessWindow
+
+# from .stareditor import StarEditor, StarRating
+from .timeline import Timeline, VideoSample
+from .standardiconswidget import StandardIconsWidget
+
+# Deprecated: should be imported from custom_delegates instead
+from prettyqt.custom_delegates.buttondelegate import ButtonDelegate
+from prettyqt.custom_delegates.radiodelegate import RadioDelegate
 
 __all__ = [
     "Image",
     "ListInput",
     "BoolDictToolButton",
     "OptionalWidget",
+    "CollapsibleFrame",
+    "CompletionWidget",
+    "ExpandableLine",
     "SingleLineTextEdit",
     "RegexInput",
     "MappedCheckBox",
-    "PromptLineEdit",
     "LogTextEdit",
     "FlagSelectionWidget",
     "StringOrNumberWidget",
     "IconLabel",
+    "IconWidget",
     "FlowLayout",
+    "BorderLayout",
     "SidebarWidget",
     "ColorChooserButton",
     "FileChooserButton",
@@ -54,6 +68,7 @@ __all__ = [
     "SpanSlider",
     "LabeledSlider",
     "WaitingSpinner",
+    "RoundProgressBar",
     "PopupInfo",
     "ButtonDelegate",
     "RadioDelegate",
@@ -61,5 +76,13 @@ __all__ = [
     "ImageViewer",
     "MarkdownWindow",
     "CodeEditor",
+    "Player",
+    "Timeline",
+    # "StarEditor",
+    # "StarRating",
+    "VideoSample",
     "RegexEditorWidget",
+    "StandardIconsWidget",
+    "SubsequenceCompleter",
+    "FramelessWindow",
 ]
