@@ -1,12 +1,17 @@
-# -*- coding: utf-8 -*-
-"""
-"""
+from __future__ import annotations
 
 from prettyqt import widgets
+from prettyqt.qt import QtWidgets
+from prettyqt.utils import types
 
 
 class ImageViewer(widgets.Widget):
-    def __init__(self, title="", path=None, parent=None):
+    def __init__(
+        self,
+        title: str = "",
+        path: types.PathType | None = None,
+        parent: QtWidgets.QWidget | None = None,
+    ):
         super().__init__(parent)
         if title:
             self.set_title(title)
@@ -19,4 +24,4 @@ class ImageViewer(widgets.Widget):
 if __name__ == "__main__":
     app = widgets.app()
     ex = ImageViewer()
-    app.exec_()
+    app.main_loop()
