@@ -1,13 +1,18 @@
-# -*- coding: utf-8 -*-
-"""
-"""
+from __future__ import annotations
 
 from prettyqt import custom_validators, widgets
+from prettyqt.qt import QtWidgets
 from prettyqt.utils import helpers
 
 
 class ListInput(widgets.LineEdit):
-    def __init__(self, default_value="", typ=int, allow_single=False, parent=None):
+    def __init__(
+        self,
+        default_value: list[float] | str = "",
+        typ: type = int,
+        allow_single: bool = False,
+        parent: QtWidgets.QWidget | None = None,
+    ):
         super().__init__(parent=parent)
         if typ is int:
             val = custom_validators.IntListValidator(allow_single=allow_single)
@@ -18,10 +23,10 @@ class ListInput(widgets.LineEdit):
         self.set_validator(val)
         self.set_value(default_value)
 
-    def get_value(self) -> list:
+    def get_value(self) -> list[float]:  # type: ignore[override]
         return helpers.string_to_num_array(self.text())
 
-    def set_value(self, value):
+    def set_value(self, value: list[float] | str):
         if isinstance(value, list):
             value = str(value)[1:-1].replace(" ", "")
         self.set_text(value)
@@ -31,5 +36,5 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = ListInput()
     widget.show()
-    app.exec_()
+    app.main_loop()
     print(widget.get_value())
