@@ -1,16 +1,16 @@
-# -*- coding: utf-8 -*-
-"""
-"""
+from __future__ import annotations
 
-from abc import ABC, abstractmethod
 import logging
 import re
 import sys
+import traceback
 
-from prettyqt import constants, gui, widgets
+from prettyqt import core, gui, widgets
 from prettyqt.utils import signallogger
 
 
+logger = logging.getLogger(__name__)
+
 # from SublimeText Regex:
 # (?x:
 #   (?:.? [<>=^])?     # fill align
@@ -24,25 +24,25 @@ from prettyqt.utils import signallogger
 # )
 
 
-class Highlighter(ABC):
+class Highlighter:
     placeholder: str
-    color = "black"
-    italic = False
-    bold = False
-    value = None
+    color: str | None = None
+    italic: bool = False
+    bold: bool = False
 
-    def __init__(self, formatter):
+    def __init__(self, formatter: logging.Formatter):
         self.formatter = formatter
         self.format = gui.TextCharFormat(self.color, self.bold, self.italic)
         text = re.escape(self.placeholder)
         pat = fr"{text[:-1]}([ +-]?\#?\#?\d*,?(?:\.\d+)?[bcdeEfFgGnosxX%]?)"
         self.pattern = re.compile(pat)
+        if self.formatter._fmt is None:
+            raise TypeError("Formatter does not contain format string")
         self.is_included = self.pattern.search(self.formatter._fmt) is not None
 
     def get_format(self, value) -> gui.TextCharFormat:
         return self.format
 
-    @abstractmethod
     def format_string(self, record: logging.LogRecord):
         raise NotImplementedError()
 
@@ -60,13 +60,13 @@ class Message(Highlighter):
     bold = True
 
     def format_string(self, record: logging.LogRecord) -> str:
-        if isinstance(record.msg, Exception):
+        if record.exc_info is not None:
             val = self.formatter.formatException(record.exc_info)
+        elif isinstance(record.msg, Exception):
+            val = traceback.format_exc()
         else:
             val = record.msg % record.args
-        if "\n" in val:
-            val = f"\n{val}"
-        return val
+        return f"\n{val}" if "\n" in val else val
 
 
 class FileName(Highlighter):
@@ -138,7 +138,8 @@ class ThreadName(Highlighter):
     bold = True
 
     def format_string(self, record: logging.LogRecord) -> str:
-        return record.threadName
+        name = record.threadName
+        return name if name else ""
 
 
 class ProcessName(Highlighter):
@@ -146,7 +147,8 @@ class ProcessName(Highlighter):
     bold = True
 
     def format_string(self, record: logging.LogRecord) -> str:
-        return record.processName
+        name = record.processName
+        return name if name else ""
 
 
 class RelativeCreated(Highlighter):
@@ -194,36 +196,31 @@ class LevelName(Highlighter):
 class LogTextEdit(widgets.PlainTextEdit):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+        self.rules = []
+        self.allow_wheel_zoom()
         self.set_font("Consolas")
-        self.formatter = None
         self.append_text(f"Python version: {sys.version}")
         logger = logging.getLogger()
         # self.handler = signallogger.LineSignalLogger()
         # self.handler.log_line.connect(self.append_text)
         self.handler = signallogger.RecordSignalLogger()
-        self.handler.log_record.connect(self.append_record)
+        self.handler.signals.log_record.connect(self.append_record)
+        core.CoreApplication.call_on_exit(lambda: logger.removeHandler(self.handler))
         self.handler.setLevel(logging.INFO)
         logger.addHandler(self.handler)
-        fmt = logging.Formatter("%(asctime)s  %(levelname)i  %(message)s")
+        fmt = logging.Formatter("%(asctime)s  %(levelname)s  %(message)s")
         self.set_formatter(fmt)
 
-    def wheelEvent(self, event):
-        """
-        handle wheel event for zooming
-        """
-        if event.modifiers() & constants.CTRL_MOD:
-            self.zoomIn() if event.angleDelta().y() > 0 else self.zoomOut()
-        else:
-            super().wheelEvent(event)
-
-    def set_formatter(self, formatter):
+    def set_formatter(self, formatter: logging.Formatter):
         self.formatter = formatter
-        self.handler.setFormatter(self.formatter)
         rules = [klass(self.formatter) for klass in Highlighter.__subclasses__()]
         self.rules = [r for r in rules if r.is_included]
+        self.handler.setFormatter(formatter)
 
-    def append_record(self, record):
+    def append_record(self, record: logging.LogRecord):
         start_of_line = len(self.text())
+        if self.formatter._fmt is None:
+            raise TypeError("Formatter does not contain format string")
         self.append_text(self.formatter._fmt)
         old_fmt = self.textCursor().charFormat()
         with self.create_cursor() as c:
@@ -272,4 +269,4 @@ if __name__ == "__main__":
     )
     w.box.add(widget)
     w.show()
-    app.exec_()
+    app.main_loop()
