@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-"""
-"""
+from __future__ import annotations
 
 from prettyqt import widgets
 from prettyqt.utils import bidict
@@ -12,11 +10,14 @@ class MappedCheckBox(widgets.CheckBox):
         dct = {True: true_value, False: false_value}
         self.map = bidict(dct)
 
+    def serialize_fields(self):
+        return dict(map=self.map)
+
     def get_value(self):
         return self.map[self.isChecked()]
 
     def set_value(self, value):
-        val = self.map.inv[value]
+        val = self.map.inverse[value]
         super().set_value(val)
 
 
@@ -24,5 +25,5 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = MappedCheckBox("Test")
     widget.show()
-    app.exec_()
+    app.main_loop()
     print(widget.get_value())
