@@ -1,17 +1,17 @@
-# -*- coding: utf-8 -*-
-"""
-"""
+from __future__ import annotations
 
-from prettyqt import gui, widgets
+from prettyqt import widgets
+from prettyqt.qt import QtWidgets
 
 
 class SingleLineTextEdit(widgets.PlainTextEdit):
-    def __init__(self, parent=None):
+    def __init__(self, parent: QtWidgets.QWidget | None = None):
         super().__init__(parent=parent)
         self.textChanged.connect(self._on_text_changed)
-        font_metrics = gui.FontMetrics(self.font())
-        self.row_height = font_metrics.lineSpacing()
-        self.setFixedHeight(self.row_height * 1.5)
+        font_metrics = self.get_font_metrics()
+        row_height = font_metrics.lineSpacing()
+        self.setFixedHeight(int(row_height * 1.5))
+        self.set_size_policy(vertical="fixed")
         self.set_line_wrap_mode("none")
         self.set_scrollbar_policy("always_off")
 
@@ -29,4 +29,4 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = SingleLineTextEdit()
     widget.show()
-    app.exec_()
+    app.main_loop()
