@@ -1,15 +1,14 @@
-# -*- coding: utf-8 -*-
-"""
-"""
 # see https://github.com/ITVRoC/SeekurJr/blob/master/seekur_12.04/packages/
 # multimaster_fkie/node_manager_fkie/src/node_manager_fkie/yaml_highlighter.py
 
 
+from __future__ import annotations
+
 from prettyqt import core, gui, syntaxhighlighters
 
 
-COMMENT_START = core.RegExp("#")
-COMMENT_END = core.RegExp("\n|\r")  # Unused?
+COMMENT_START = core.RegularExpression("#")
+COMMENT_END = core.RegularExpression("\n|\r")  # Unused?
 COMMENT_FORMAT = gui.TextCharFormat()
 COMMENT_FORMAT.setFontItalic(True)
 COMMENT_FORMAT.set_foreground_color("darkgray")
@@ -86,7 +85,7 @@ class YamlHighlighter(gui.SyntaxHighlighter):
         self.setCurrentBlockState(0)
         start_index = 0
         if self.previousBlockState() != 1:
-            start_index = COMMENT_START.indexIn(text)
+            start_index = COMMENT_START.match(text).capturedStart()
             if start_index >= 0:
                 comment_len = len(text) - start_index
                 self.setFormat(start_index, comment_len, COMMENT_FORMAT)
@@ -99,4 +98,4 @@ if __name__ == "__main__":
     editor = widgets.PlainTextEdit()
     highlighter = YamlHighlighter(editor.document())
     editor.show()
-    app.exec_()
+    app.main_loop()
