@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
-"""
-"""
-
-from qtpy import QtWidgets
+from __future__ import annotations
 
 from prettyqt import core, widgets
+from prettyqt.qt import QtWidgets
 
 
 QtWidgets.QCommandLinkButton.__bases__ = (widgets.PushButton,)
@@ -19,4 +16,4 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = CommandLinkButton("This is a test")
     widget.show()
-    app.exec_()
+    app.main_loop()
