@@ -1,57 +1,74 @@
-# -*- coding: utf-8 -*-
-"""
-"""
+from __future__ import annotations
 
-from typing import Any, Callable, Optional, Union
+from collections.abc import Iterator
+from typing import Any, Callable
 
-from qtpy import QtWidgets
-
-from prettyqt import core, widgets
-from prettyqt.utils import icons
+from prettyqt import core, gui, iconprovider, widgets
+from prettyqt.qt import QtWidgets
+from prettyqt.utils import types
 
 
 QtWidgets.QMenu.__bases__ = (widgets.Widget,)
 
 
 class Menu(QtWidgets.QMenu):
-    def __init__(self, title: str = "", icon: icons.IconType = None, parent=None):
+    def __init__(
+        self,
+        title: str = "",
+        icon: types.IconType = None,
+        parent: QtWidgets.QWidget | None = None,
+    ):
         super().__init__(title, parent=parent)
         self.set_icon(icon)
         self.setToolTipsVisible(True)
 
-    def __iter__(self):
+    def __iter__(self) -> Iterator[QtWidgets.QAction]:
         return iter(self.actions())
 
-    def __len__(self):
+    def __len__(self) -> int:
         return len(self.actions())
 
-    def __add__(self, other):
-        if isinstance(other, QtWidgets.QAction):
-            self.add(other)
-            return self
-        raise TypeError("Invalid Type")
+    def __add__(self, other: QtWidgets.QAction):
+        self.add(other)
+        return self
 
-    def __getitem__(self, item):
+    def __getitem__(self, item: str) -> QtWidgets.QAction:
         for action in self.actions():
-            if action.id == item:
+            if action.objectName() == item:
                 return action
         raise KeyError(f"Action {item} not in menu")
 
-    def add(self, *item):
-        for i in item:
-            self.add_action(i)
+    def serialize_fields(self):
+        return dict(
+            separators_collapsible=self.separatorsCollapsible(),
+            tearoff_enabled=self.isTearOffEnabled(),
+            title=self.title(),
+            tool_tips_visible=self.toolTipsVisible(),
+            icon=self.get_icon(),
+        )
 
-    def set_icon(self, icon: icons.IconType):
-        """set the icon for the menu
+    def add(self, *item: QtWidgets.QAction):
+        for i in item:
+            i.setParent(self)
+            self.addAction(i)
+
+    def set_icon(self, icon: types.IconType):
+        """Set the icon for the menu.
 
         Args:
             icon: icon to use
         """
-        icon = icons.get_icon(icon)
+        icon = iconprovider.get_icon(icon)
         self.setIcon(icon)
 
-    def add_separator(self, text: Optional[str] = None) -> widgets.WidgetAction:
-        """adds a separator showing an optional label
+    def get_icon(self) -> gui.Icon | None:
+        icon = self.icon()
+        if icon.isNull():
+            return None
+        return gui.Icon(icon)
+
+    def add_separator(self, text: str | None = None) -> widgets.WidgetAction:
+        """Adds a separator showing an optional label.
 
         Args:
             text: Text to show on separator
@@ -65,24 +82,25 @@ class Menu(QtWidgets.QMenu):
         else:
             label = widgets.Label(text)
             label.setMinimumWidth(self.minimumWidth())
-            label.setStyleSheet("background:lightgrey")
+            with label.edit_stylesheet() as ss:
+                ss.background.setValue("lightgrey")
             label.set_alignment(horizontal="center")
-            separator = widgets.WidgetAction(parent=self)
             separator.setDefaultWidget(label)
+            separator.setEnabled(False)
         self.add(separator)
         return separator
 
     def add_action(
         self,
-        label: Union[str, widgets.Action],
+        label: str | widgets.Action,
         callback: Callable = None,
-        icon: Optional[Any] = None,
+        icon: Any | None = None,
         checkable: bool = False,
         checked: bool = False,
-        shortcut: Optional[str] = None,
-        status_tip: Optional[str] = None,
+        shortcut: str | None = None,
+        status_tip: str | None = None,
     ) -> widgets.Action:
-        """Add an action to the menu
+        """Add an action to the menu.
 
         Args:
             label: Label for button
@@ -113,11 +131,13 @@ class Menu(QtWidgets.QMenu):
         self.addAction(action)
         return action
 
-    def add_actions(self, actions):
+    def add_actions(self, actions: list[QtWidgets.QAction]):
         self.addActions(actions)
 
-    def add_menu(self, menu: QtWidgets.QMenu):
-        return self.addAction(menu.menuAction())
+    def add_menu(self, menu: QtWidgets.QMenu) -> QtWidgets.QAction:
+        action = menu.menuAction()
+        self.addAction(action)
+        return action
 
 
 if __name__ == "__main__":
