@@ -1,22 +1,19 @@
-# -*- coding: utf-8 -*-
-"""
-"""
-
-from qtpy import QtWidgets
+from __future__ import annotations
 
 from prettyqt import widgets
+from prettyqt.qt import QtWidgets
 
 
-QtWidgets.QProgressDialog.__bases__ = (widgets.BaseDialog,)
+QtWidgets.QProgressDialog.__bases__ = (widgets.Dialog,)
 
 
 class ProgressDialog(QtWidgets.QProgressDialog):
-    """Progress dialog
+    """Progress dialog.
 
-    wrapper for QtWidgets.QProgressDialog
+    Wrapper for QtWidgets.QProgressDialog
     """
 
-    def __init__(self, parent=None):
+    def __init__(self, parent: QtWidgets.QWidget | None = None):
         super().__init__(parent=parent)
 
         progress_bar = widgets.ProgressBar()
@@ -29,10 +26,10 @@ class ProgressDialog(QtWidgets.QProgressDialog):
         self.set_flags(
             minimize=False, maximize=False, close=False, stay_on_top=True, window=True
         )
-        self.setCancelButton(None)
+        self.setCancelButton(None)  # type: ignore
         self.cancel()
 
-    def show_message(self, message):
+    def show_message(self, message: str):
         self.setLabelText(message)
         self.show()
 
@@ -41,4 +38,4 @@ if __name__ == "__main__":
     app = widgets.app()
     widget = ProgressDialog()
     widget.show_message("test")
-    widget.exec_()
+    widget.main_loop()
