@@ -1,10 +1,9 @@
-# -*- coding: utf-8 -*-
-"""
-"""
+from __future__ import annotations
 
-from qtpy import QtWidgets
+from typing import Callable
 
 from prettyqt import core, widgets
+from prettyqt.qt import QtWidgets
 
 
 QtWidgets.QPushButton.__bases__ = (widgets.AbstractButton,)
@@ -14,29 +13,22 @@ class PushButton(QtWidgets.QPushButton):
 
     value_changed = core.Signal(bool)
 
-    def __init__(self, label=None, parent=None, callback=None):
+    def __init__(
+        self,
+        label: str | None = None,
+        parent: QtWidgets.QWidget | None = None,
+        callback: Callable | None = None,
+    ):
+        if label is None:
+            label = ""
         super().__init__(label, parent)
         if callback:
             self.clicked.connect(callback)
         self.toggled.connect(self.value_changed)
 
-    def get_value(self):
-        return self.isChecked()
-
-    def set_value(self, value):
-        self.setChecked(value)
-
-    @property
-    def is_on(self) -> bool:
-        return self.isChecked()
-
-    @is_on.setter
-    def is_on(self, state: bool):
-        self.setChecked(state)
-
 
 if __name__ == "__main__":
     app = widgets.app()
     widget = PushButton("This is a test")
     widget.show()
-    app.exec_()
+    app.main_loop()
