@@ -1,36 +1,34 @@
-# -*- coding: utf-8 -*-
-"""
-@author: Philipp Temminghoff
-"""
+from __future__ import annotations
 
-from qtpy import QtWidgets
 from prettyqt import widgets
+from prettyqt.qt import QtWidgets
 
 
 QtWidgets.QStackedLayout.__bases__ = (widgets.Layout,)
 
 
 class StackedLayout(QtWidgets.QStackedLayout):
-
-    def __getstate__(self):
+    def serialize_fields(self):
         return dict(items=self.get_children())
 
     def __setstate__(self, state):
-        self.__init__()
         for item in state["items"]:
             self.add(item)
 
-    def __add__(self, other):
-        if isinstance(other, (QtWidgets.QWidget, QtWidgets.QLayout)):
-            self.add(other)
-            return self
+    def __reduce__(self):
+        return type(self), (), self.__getstate__()
 
-    def set_current_widget(self, widget):
+    def __add__(self, other: QtWidgets.QWidget | QtWidgets.QLayout):
+        self.add(other)
+        return self
+
+    def set_current_widget(self, widget: QtWidgets.QWidget):
         self.setCurrentWidget(widget)
 
 
 if __name__ == "__main__":
     from prettyqt import widgets
+
     app = widgets.app()
     layout = StackedLayout()
     widget = widgets.Widget()
@@ -40,4 +38,4 @@ if __name__ == "__main__":
     layout += widget3
     widget.set_layout(layout)
     widget.show()
-    app.exec_()
+    app.main_loop()
